@@ -26,12 +26,15 @@ public:
 
     void setFont() const;
     void setIconTheme() const;
+    void setSoundTheme() const;
+    void setEventSoundsEnabled() const;
     void setCursorTheme() const;
     void setCursorSize() const;
     void setIconsOnButtons() const;
     void setIconsInMenus() const;
     void setToolbarStyle() const;
     void setScrollbarBehavior() const;
+    void setDoubleClickInterval() const;
     void setDarkThemePreference() const;
     void setWindowDecorationsAppearance() const;
     void setWindowDecorationsButtonsOrder() const;
@@ -61,6 +64,7 @@ private:
     KConfigWatcher::Ptr kcmfontsConfigWatcher;
     KConfigWatcher::Ptr kcminputConfigWatcher;
     KConfigWatcher::Ptr breezeConfigWatcher;
+    void setGtk2Theme(const QString &themeName, const bool preferDarkTheme) const;
 
     GSDXSettingsManager *m_gsdXsettingsManager = nullptr;
 };
